@@ -1,6 +1,6 @@
 # --
 # Kernel/Modules/AdminDynamicFieldDropdown.pm - provides a dynamic fields text config view for admins
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -38,7 +38,7 @@ sub new {
     $Self->{ObjectTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::ObjectType');
 
     # get the fields config
-    $Self->{FieldTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::Backend') || {};
+    $Self->{FieldTypeConfig} = $Self->{ConfigObject}->Get('DynamicFields::Driver') || {};
 
     # set possible values handling strings
     $Self->{EmptyString}     = '_DynamicFields_EmptyString_Dont_Use_It_String_Please';
@@ -124,6 +124,10 @@ sub _AddAction {
         }
     }
 
+    # get the TreeView option and set it to '0' if it is undefined
+    $GetParam{TreeView} = $Self->{ParamObject}->GetParam( Param => 'TreeView' );
+    $GetParam{TreeView} = defined $GetParam{TreeView} && $GetParam{TreeView} ? '1' : '0';
+
     if ( $GetParam{Name} ) {
 
         # check if name is alphanumeric
@@ -223,6 +227,7 @@ sub _AddAction {
     # set specific config
     my $FieldConfig = {
         PossibleValues     => $PossibleValues,
+        TreeView           => $GetParam{TreeView},
         DefaultValue       => $GetParam{DefaultValue},
         PossibleNone       => $GetParam{PossibleNone},
         TranslatableValues => $GetParam{TranslatableValues},
@@ -306,9 +311,12 @@ sub _Change {
         # set PossibleNone
         $Config{PossibleNone} = $DynamicFieldData->{Config}->{PossibleNone};
 
-        # set TranslatalbeValues
+        # set TranslatableValues
         $Config{TranslatableValues} = $DynamicFieldData->{Config}->{TranslatableValues};
 
+        # set TreeView
+        $Config{TreeView} = $DynamicFieldData->{Config}->{TreeView};
+
         # set Link
         $Config{Link} = $DynamicFieldData->{Config}->{Link};
     }
@@ -339,6 +347,10 @@ sub _ChangeAction {
         }
     }
 
+    # get the TreeView option and set it to '0' if it is undefined
+    $GetParam{TreeView} = $Self->{ParamObject}->GetParam( Param => 'TreeView' );
+    $GetParam{TreeView} = defined $GetParam{TreeView} && $GetParam{TreeView} ? '1' : '0';
+
     my $FieldID = $Self->{ParamObject}->GetParam( Param => 'ID' );
     if ( !$FieldID ) {
         return $Self->{LayoutObject}->ErrorScreen(
@@ -475,6 +487,7 @@ sub _ChangeAction {
     # set specific config
     my $FieldConfig = {
         PossibleValues     => $PossibleValues,
+        TreeView           => $GetParam{TreeView},
         DefaultValue       => $GetParam{DefaultValue},
         PossibleNone       => $GetParam{PossibleNone},
         TranslatableValues => $GetParam{TranslatableValues},
@@ -528,8 +541,10 @@ sub _ShowScreen {
 
     # get the list of order numbers (is already sorted).
     my @DynamicfieldOrderList;
+    my %DynamicfieldNamesList;
     for my $Dynamicfield ( @{$DynamicFieldList} ) {
         push @DynamicfieldOrderList, $Dynamicfield->{FieldOrder};
+        $DynamicfieldNamesList{ $Dynamicfield->{FieldOrder} } = $Dynamicfield->{Label};
     }
 
     # when adding we need to create an extra order number for the new field
@@ -543,13 +558,27 @@ sub _ShowScreen {
         push @DynamicfieldOrderList, $LastOrderNumber;
     }
 
-    my $DynamicFieldOrderSrtg = $Self->{LayoutObject}->BuildSelection(
-        Data          => \@DynamicfieldOrderList,
+    # show the names of the other fields to ease ordering
+    my %OrderNamesList;
+    my $CurrentlyText = $Self->{LayoutObject}->{LanguageObject}->Get('Currently') . ': ';
+    for my $OrderNumber ( sort @DynamicfieldOrderList ) {
+        $OrderNamesList{$OrderNumber} = $OrderNumber;
+        if ( $DynamicfieldNamesList{$OrderNumber} && $OrderNumber ne $Param{FieldOrder} ) {
+            $OrderNamesList{$OrderNumber}
+                = $OrderNumber . ' - '
+                . $CurrentlyText
+                . $DynamicfieldNamesList{$OrderNumber}
+        }
+    }
+
+    my $DynamicFieldOrderStrg = $Self->{LayoutObject}->BuildSelection(
+        Data          => \%OrderNamesList,
         Name          => 'FieldOrder',
         SelectedValue => $Param{FieldOrder} || 1,
         PossibleNone  => 0,
         Translation   => 0,
-        Class         => 'W50pc Validate_Number',
+        Sort          => 'NumericKey',
+        Class         => 'W75pc Validate_Number',
     );
 
     my %ValidList = $Self->{ValidObject}->ValidList();
@@ -697,6 +726,19 @@ sub _ShowScreen {
         Class      => 'W50pc',
     );
 
+    my $TreeView = $Param{TreeView} || '0';
+
+    # create treeview option list
+    my $TreeViewStrg = $Self->{LayoutObject}->BuildSelection(
+        Data => {
+            0 => 'No',
+            1 => 'Yes',
+        },
+        Name       => 'TreeView',
+        SelectedID => $TreeView,
+        Class      => 'W50pc',
+    );
+
     my $Link = $Param{Link} || '';
 
     my $ReadonlyInternalField = '';
@@ -716,10 +758,11 @@ sub _ShowScreen {
         Data         => {
             %Param,
             ValidityStrg           => $ValidityStrg,
-            DynamicFieldOrderSrtg  => $DynamicFieldOrderSrtg,
+            DynamicFieldOrderStrg  => $DynamicFieldOrderStrg,
             ValueCounter           => $ValueCounter,
             DefaultValueStrg       => $DefaultValueStrg,
             PossibleNoneStrg       => $PossibleNoneStrg,
+            TreeViewStrg           => $TreeViewStrg,
             TranslatableValuesStrg => $TranslatableValuesStrg,
             ReadonlyInternalField  => $ReadonlyInternalField,
             Link                   => $Link,
