@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AdminService.pm - admin frontend to manage services
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
-# --
-# $Id: AdminService.pm,v 1.35.2.2 2012-06-05 10:22:51 ub Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Kernel::System::Service;
 use Kernel::System::Valid;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.35.2.2 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -234,6 +229,7 @@ sub Run {
                     },
                 );
             }
+
         }
 
         # otherwise a no data found msg is displayed
@@ -278,6 +274,9 @@ sub _MaskNew {
     $Self->{LayoutObject}->Block( Name => 'ActionList' );
     $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
+    # get list type
+    my $ListType = $Self->{ConfigObject}->Get('Ticket::Frontend::ListType');
+
     # generate ParentOptionStrg
     my %ServiceList = $Self->{ServiceObject}->ServiceList(
         Valid  => 0,
@@ -288,6 +287,7 @@ sub _MaskNew {
         Name           => 'ParentID',
         SelectedID     => $Param{ParentID} || $ServiceData{ParentID},
         PossibleNone   => 1,
+        TreeView       => ( $ListType eq 'tree' ) ? 1 : 0,
         DisabledBranch => $ServiceData{Name},
         Translation    => 0,
     );
