@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/Modules/AdminTemplate.pm - provides admin std template module
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminTemplate;
@@ -11,9 +12,10 @@ package Kernel::Modules::AdminTemplate;
 use strict;
 use warnings;
 
-use Kernel::Language qw(Translatable);
-
-our $ObjectManagerDisabled = 1;
+use Kernel::System::StandardTemplate;
+use Kernel::System::StdAttachment;
+use Kernel::System::Valid;
+use Kernel::System::HTMLUtils;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -22,51 +24,51 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check all needed objects
+    for my $Needed (qw(ParamObject DBObject LayoutObject ConfigObject LogObject)) {
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
+        }
+    }
+    $Self->{StandardTemplateObject} = Kernel::System::StandardTemplate->new(%Param);
+    $Self->{StdAttachmentObject}    = Kernel::System::StdAttachment->new(%Param);
+    $Self->{ValidObject}            = Kernel::System::Valid->new(%Param);
+    $Self->{HTMLUtilsObject}        = Kernel::System::HTMLUtils->new(%Param);
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject            = $Kernel::OM->Get('Kernel::System::Web::Request');
-    my $LayoutObject           = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
-    my $StdAttachmentObject    = $Kernel::OM->Get('Kernel::System::StdAttachment');
-
-    my $Notification = $ParamObject->GetParam( Param => 'Notification' ) || '';
-
     # ------------------------------------------------------------ #
     # change
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'Change' ) {
-        my $ID   = $ParamObject->GetParam( Param => 'ID' ) || '';
-        my %Data = $StandardTemplateObject->StandardTemplateGet(
-            ID => $ID,
-        );
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' ) || '';
+        my %Data = $Self->{StandardTemplateObject}->StandardTemplateGet( ID => $ID, );
 
         my @SelectedAttachment;
-        my %SelectedAttachmentData = $StdAttachmentObject->StdAttachmentStandardTemplateMemberList(
+        my %SelectedAttachmentData
+            = $Self->{StdAttachmentObject}->StdAttachmentStandardTemplateMemberList(
             StandardTemplateID => $ID,
-        );
+            );
         for my $Key ( sort keys %SelectedAttachmentData ) {
             push @SelectedAttachment, $Key;
         }
 
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Info => Translatable('Template updated!') )
-            if ( $Notification && $Notification eq 'Update' );
-
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Change',
             %Data,
             SelectedAttachments => \@SelectedAttachment,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminTemplate',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -76,22 +78,17 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'ChangeAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my @NewIDs = $ParamObject->GetArray( Param => 'IDs' );
+        my @NewIDs = $Self->{ParamObject}->GetArray( Param => 'IDs' );
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Comment ValidID TemplateType)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Comment ValidID Template TemplateType)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        $GetParam{'Template'} = $ParamObject->GetParam(
-            Param => 'Template',
-            Raw   => 1
-        ) || '';
-
         # get composed content type
         $GetParam{ContentType} = 'text/plain';
-        if ( $LayoutObject->{BrowserRichText} ) {
+        if ( $Self->{LayoutObject}->{BrowserRichText} ) {
             $GetParam{ContentType} = 'text/html';
         }
 
@@ -102,29 +99,18 @@ sub Run {
             }
         }
 
-        # check if a standard template exist with this name
-        my $NameExists = $StandardTemplateObject->NameExistsCheck(
-            Name => $GetParam{Name},
-            ID   => $GetParam{ID}
-        );
-
-        if ($NameExists) {
-            $Errors{NameExists}    = 1;
-            $Errors{'NameInvalid'} = 'ServerError';
-        }
-
         # if no errors occurred
         if ( !%Errors ) {
 
             # update group
             if (
-                $StandardTemplateObject->StandardTemplateUpdate(
+                $Self->{StandardTemplateObject}->StandardTemplateUpdate(
                     %GetParam,
                     UserID => $Self->{UserID},
                 )
                 )
             {
-                my %AttachmentsAll = $StdAttachmentObject->StdAttachmentList();
+                my %AttachmentsAll = $Self->{StdAttachmentObject}->StdAttachmentList();
 
                 # create hash with selected queues
                 my %AttachmentsSelected = map { $_ => 1 } @NewIDs;
@@ -134,48 +120,43 @@ sub Run {
                     my $Active = $AttachmentsSelected{$AttachmentID} ? 1 : 0;
 
                     # set attachment to standard template relation
-                    my $Success = $StdAttachmentObject->StdAttachmentStandardTemplateMemberAdd(
+                    my $Success
+                        = $Self->{StdAttachmentObject}->StdAttachmentStandardTemplateMemberAdd(
                         AttachmentID       => $AttachmentID,
                         StandardTemplateID => $GetParam{ID},
                         Active             => $Active,
                         UserID             => $Self->{UserID},
-                    );
+                        );
                 }
 
-                # if the user would like to continue editing the template, just redirect to the edit screen
-                if (
-                    defined $ParamObject->GetParam( Param => 'ContinueAfterSave' )
-                    && ( $ParamObject->GetParam( Param => 'ContinueAfterSave' ) eq '1' )
-                    )
-                {
-                    my $ID = $ParamObject->GetParam( Param => 'ID' ) || '';
-                    return $LayoutObject->Redirect(
-                        OP => "Action=$Self->{Action};Subaction=Change;ID=$ID;Notification=Update"
-                    );
-                }
-                else {
-
-                    # otherwise return to overview
-                    return $LayoutObject->Redirect( OP => "Action=$Self->{Action};Notification=Update" );
-                }
+                $Self->_Overview();
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Template updated!' );
+                $Output .= $Self->{LayoutObject}->Output(
+                    TemplateFile => 'AdminTemplate',
+                    Data         => \%Param,
+                );
+                $Output .= $Self->{LayoutObject}->Footer();
+                return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action              => 'Change',
             Errors              => \%Errors,
             SelectedAttachments => \@NewIDs,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminTemplate',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -184,18 +165,18 @@ sub Run {
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Add' ) {
         my %GetParam;
-        $GetParam{Name} = $ParamObject->GetParam( Param => 'Name' );
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
+        $GetParam{Name} = $Self->{ParamObject}->GetParam( Param => 'Name' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action => 'Add',
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminTemplate',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -205,23 +186,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddAction' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my @NewIDs = $ParamObject->GetArray( Param => 'IDs' );
+        my @NewIDs = $Self->{ParamObject}->GetArray( Param => 'IDs' );
         my ( %GetParam, %Errors );
 
-        for my $Parameter (qw(ID Name Comment ValidID TemplateType)) {
-            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+        for my $Parameter (qw(ID Name Comment ValidID Template TemplateType)) {
+            $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
 
-        $GetParam{'Template'} = $ParamObject->GetParam(
-            Param => 'Template',
-            Raw   => 1
-        ) || '';
-
         # get composed content type
         $GetParam{ContentType} = 'text/plain';
-        if ( $LayoutObject->{BrowserRichText} ) {
+        if ( $Self->{LayoutObject}->{BrowserRichText} ) {
             $GetParam{ContentType} = 'text/html';
         }
 
@@ -232,24 +208,18 @@ sub Run {
             }
         }
 
-        # check if a standard template exists with this name
-        my $NameExists = $StandardTemplateObject->NameExistsCheck( Name => $GetParam{Name} );
-        if ($NameExists) {
-            $Errors{NameExists}    = 1;
-            $Errors{'NameInvalid'} = 'ServerError';
-        }
-
         # if no errors occurred
         if ( !%Errors ) {
 
             # add template
-            my $StandardTemplateID = $StandardTemplateObject->StandardTemplateAdd(
+            my $StandardTemplateID
+                = $Self->{StandardTemplateObject}->StandardTemplateAdd(
                 %GetParam,
                 UserID => $Self->{UserID},
-            );
+                );
             if ($StandardTemplateID) {
 
-                my %AttachmentsAll = $StdAttachmentObject->StdAttachmentList();
+                my %AttachmentsAll = $Self->{StdAttachmentObject}->StdAttachmentList();
 
                 # create hash with selected queues
                 my %AttachmentsSelected = map { $_ => 1 } @NewIDs;
@@ -259,44 +229,43 @@ sub Run {
                     my $Active = $AttachmentsSelected{$AttachmentID} ? 1 : 0;
 
                     # set attachment to standard template relation
-                    my $Success = $StdAttachmentObject->StdAttachmentStandardTemplateMemberAdd(
+                    my $Success
+                        = $Self->{StdAttachmentObject}->StdAttachmentStandardTemplateMemberAdd(
                         AttachmentID       => $AttachmentID,
                         StandardTemplateID => $StandardTemplateID,
                         Active             => $Active,
                         UserID             => $Self->{UserID},
-                    );
+                        );
                 }
 
                 $Self->_Overview();
-                my $Output = $LayoutObject->Header();
-                $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Notify(
-                    Info => Translatable('Template added!'),
-                );
-                $Output .= $LayoutObject->Output(
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Notify( Info => 'Template added!' );
+                $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminTemplate',
                     Data         => \%Param,
                 );
-                $Output .= $LayoutObject->Footer();
+                $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
         }
 
         # something has gone wrong
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Priority => 'Error' );
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Notify( Priority => 'Error' );
         $Self->_Edit(
             Action              => 'Add',
             Errors              => \%Errors,
             SelectedAttachments => \@NewIDs,
             %GetParam,
         );
-        $Output .= $LayoutObject->Output(
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminTemplate',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -306,23 +275,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'Delete' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
-        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my $ID = $Self->{ParamObject}->GetParam( Param => 'ID' );
 
-        my $Delete = $StandardTemplateObject->StandardTemplateDelete(
+        my $Delete = $Self->{StandardTemplateObject}->StandardTemplateDelete(
             ID => $ID,
         );
         if ( !$Delete ) {
-            return $LayoutObject->ErrorScreen();
+            return $Self->{LayoutObject}->ErrorScreen();
         }
 
-        return $LayoutObject->Attachment(
-            ContentType => 'text/html',
-            Content     => $Delete,
-            Type        => 'inline',
-            NoCache     => 1,
-        );
+        return $Self->{LayoutObject}->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------
@@ -330,16 +294,13 @@ sub Run {
     # ------------------------------------------------------------
     else {
         $Self->_Overview();
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Notify( Info => Translatable('Template updated!') )
-            if ( $Notification && $Notification eq 'Update' );
-
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminTemplate',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 }
@@ -347,38 +308,36 @@ sub Run {
 sub _Edit {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $LayoutObject->Block( Name => 'ActionList' );
-    $LayoutObject->Block( Name => 'ActionOverview' );
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
     # get valid list
-    my %ValidList        = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+    my %ValidList        = $Self->{ValidObject}->ValidList();
     my %ValidListReverse = reverse %ValidList;
 
-    $Param{ValidOption} = $LayoutObject->BuildSelection(
+    $Param{ValidOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => \%ValidList,
         Name       => 'ValidID',
         SelectedID => $Param{ValidID} || $ValidListReverse{valid},
-        Class      => 'Modernize Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'ValidIDInvalid'} || '' ),
     );
 
-    my $TemplateTypeList = $Kernel::OM->Get('Kernel::Config')->Get('StandardTemplate::Types');
+    my $TemplateTypeList = $Self->{ConfigObject}->Get('StandardTemplate::Types');
 
-    $Param{TemplateTypeString} = $LayoutObject->BuildSelection(
+    $Param{TemplateTypeString} = $Self->{LayoutObject}->BuildSelection(
         Data       => $TemplateTypeList,
         Name       => 'TemplateType',
         SelectedID => $Param{TemplateType},
-        Class      => 'Modernize Validate_Required ' . ( $Param{Errors}->{'TemplateTypeInvalid'} || '' ),
+        Class      => 'Validate_Required ' . ( $Param{Errors}->{'TemplateTypeInvalid'} || '' ),
     );
 
-    my %AttachmentData = $Kernel::OM->Get('Kernel::System::StdAttachment')->StdAttachmentList( Valid => 1 );
-    $Param{AttachmentOption} = $LayoutObject->BuildSelection(
+    my %AttachmentData = $Self->{StdAttachmentObject}->StdAttachmentList( Valid => 1 );
+    $Param{AttachmentOption} = $Self->{LayoutObject}->BuildSelection(
         Data         => \%AttachmentData,
         Name         => 'IDs',
         Multiple     => 1,
@@ -386,16 +345,34 @@ sub _Edit {
         Translation  => 0,
         PossibleNone => 1,
         SelectedID   => $Param{SelectedAttachments},
-        Class        => 'Modernize',
     );
 
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
+    $Self->{LayoutObject}->Block(
+        Name => 'OverviewUpdate',
+        Data => {
+            %Param,
+            %{ $Param{Errors} },
+        },
+    );
 
-    if ( $LayoutObject->{BrowserRichText} ) {
+    # shows header
+    if ( $Param{Action} eq 'Change' ) {
+        $Self->{LayoutObject}->Block( Name => 'HeaderEdit' );
+    }
+    else {
+        $Self->{LayoutObject}->Block( Name => 'HeaderAdd' );
+    }
+
+    # add rich text editor
+    if ( $Self->{LayoutObject}->{BrowserRichText} ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'RichText',
+            Data => \%Param,
+        );
 
         # reformat from plain to html
         if ( $Param{ContentType} && $Param{ContentType} =~ /text\/plain/i ) {
-            $Param{Template} = $HTMLUtilsObject->ToHTML(
+            $Param{Template} = $Self->{HTMLUtilsObject}->ToHTML(
                 String => $Param{Template},
             );
         }
@@ -404,60 +381,31 @@ sub _Edit {
 
         # reformat from html to plain
         if ( $Param{ContentType} && $Param{ContentType} =~ /text\/html/i ) {
-            $Param{Template} = $HTMLUtilsObject->ToAscii(
+            $Param{Template} = $Self->{HTMLUtilsObject}->ToAscii(
                 String => $Param{Template},
             );
         }
     }
-
-    $LayoutObject->Block(
-        Name => 'OverviewUpdate',
-        Data => {
-            %Param,
-            %{ $Param{Errors} },
-        },
-    );
-
-    # show appropriate messages for ServerError
-    if ( defined $Param{Errors}->{NameExists} && $Param{Errors}->{NameExists} == 1 ) {
-        $LayoutObject->Block( Name => 'ExistNameServerError' );
-    }
-    else {
-        $LayoutObject->Block( Name => 'NameServerError' );
-    }
-
-    # add rich text editor
-    if ( $LayoutObject->{BrowserRichText} ) {
-
-        # set up rich text editor
-        $LayoutObject->SetRichTextParameters(
-            Data => \%Param,
-        );
-    }
     return 1;
 }
 
 sub _Overview {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Overview',
         Data => \%Param,
     );
 
-    $LayoutObject->Block( Name => 'ActionList' );
-    $LayoutObject->Block( Name => 'ActionAdd' );
-    $LayoutObject->Block( Name => 'Filter' );
+    $Self->{LayoutObject}->Block( Name => 'ActionList' );
+    $Self->{LayoutObject}->Block( Name => 'ActionAdd' );
+    $Self->{LayoutObject}->Block( Name => 'Filter' );
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'OverviewResult',
         Data => \%Param,
     );
-
-    my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
-    my %List                   = $StandardTemplateObject->StandardTemplateList(
+    my %List = $Self->{StandardTemplateObject}->StandardTemplateList(
         UserID => 1,
         Valid  => 0,
     );
@@ -467,27 +415,25 @@ sub _Overview {
 
         my %ListGet;
         for my $ID ( sort keys %List ) {
-            %{ $ListGet{$ID} } = $StandardTemplateObject->StandardTemplateGet(
-                ID => $ID,
-            );
+            %{ $ListGet{$ID} } = $Self->{StandardTemplateObject}->StandardTemplateGet( ID => $ID, );
             $ListGet{$ID}->{SortName} = $ListGet{$ID}->{TemplateType} . $ListGet{$ID}->{Name};
         }
 
         # get valid list
-        my %ValidList = $Kernel::OM->Get('Kernel::System::Valid')->ValidList();
+        my %ValidList = $Self->{ValidObject}->ValidList();
         for my $ID ( sort { $ListGet{$a}->{SortName} cmp $ListGet{$b}->{SortName} } keys %ListGet )
         {
 
             my %Data = %{ $ListGet{$ID} };
             my @SelectedAttachment;
             my %SelectedAttachmentData
-                = $Kernel::OM->Get('Kernel::System::StdAttachment')->StdAttachmentStandardTemplateMemberList(
+                = $Self->{StdAttachmentObject}->StdAttachmentStandardTemplateMemberList(
                 StandardTemplateID => $ID,
                 );
             for my $Key ( sort keys %SelectedAttachmentData ) {
                 push @SelectedAttachment, $Key;
             }
-            $LayoutObject->Block(
+            $Self->{LayoutObject}->Block(
                 Name => 'OverviewResultRow',
                 Data => {
                     Valid => $ValidList{ $Data{ValidID} },
@@ -500,7 +446,7 @@ sub _Overview {
 
     # otherwise it displays a no data found message
     else {
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'NoDataFoundMsg',
             Data => {},
         );
