@@ -1,5 +1,6 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Scheduler/TaskHandler/RegistrationUpdate.pm - Scheduler task handler RegistrationUpdate backend
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -92,10 +93,7 @@ sub Run {
         Priority => 'info',
         Message  => "Registration - RegistrationUpdate running.",
     );
-
-    my %Result = $Self->{RegistrationObject}->RegistrationUpdateSend(
-        RegistrationUpdateTaskID => $Param{TaskID},
-    );
+    my %Result = $Self->{RegistrationObject}->RegistrationUpdateSend();
 
     # if we sent a successful Update, reschedule in whatever the OTRS
     # portal tells us. Otherwise, retry in two hours
