@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Auth/Sync/LDAP.pm - provides the ldap sync
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -54,28 +54,35 @@ sub new {
         );
         return;
     }
-    $Self->{Count}        = $Param{Count} || '';
-    $Self->{Die}          = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Die' . $Param{Count} );
-    $Self->{Host}         = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Host' . $Param{Count} );
-    $Self->{BaseDN}       = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::BaseDN' . $Param{Count} );
-    $Self->{UID}          = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UID' . $Param{Count} );
-    $Self->{SearchUserDN} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::SearchUserDN' . $Param{Count} ) || '';
-    $Self->{SearchUserPw} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::SearchUserPw' . $Param{Count} ) || '';
-    $Self->{GroupDN}      = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::GroupDN' . $Param{Count} )
+    $Self->{Count}  = $Param{Count} || '';
+    $Self->{Die}    = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Die' . $Param{Count} );
+    $Self->{Host}   = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Host' . $Param{Count} );
+    $Self->{BaseDN} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::BaseDN' . $Param{Count} );
+    $Self->{UID}    = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UID' . $Param{Count} );
+    $Self->{SearchUserDN}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::SearchUserDN' . $Param{Count} ) || '';
+    $Self->{SearchUserPw}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::SearchUserPw' . $Param{Count} ) || '';
+    $Self->{GroupDN} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::GroupDN' . $Param{Count} )
         || '';
-    $Self->{AccessAttr} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::AccessAttr' . $Param{Count} )
+    $Self->{AccessAttr}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::AccessAttr' . $Param{Count} )
         || 'memberUid';
-    $Self->{UserAttr} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UserAttr' . $Param{Count} )
+    $Self->{UserAttr}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UserAttr' . $Param{Count} )
         || 'DN';
-    $Self->{DestCharset} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Charset' . $Param{Count} )
+    $Self->{DestCharset}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Charset' . $Param{Count} )
         || 'utf-8';
 
     # ldap filter always used
-    $Self->{AlwaysFilter} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::AlwaysFilter' . $Param{Count} ) || '';
+    $Self->{AlwaysFilter}
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::AlwaysFilter' . $Param{Count} ) || '';
 
     # Net::LDAP new params
     if ( $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Params' . $Param{Count} ) ) {
-        $Self->{Params} = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Params' . $Param{Count} );
+        $Self->{Params}
+            = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::Params' . $Param{Count} );
     }
     else {
         $Self->{Params} = {};
@@ -89,10 +96,7 @@ sub Sync {
 
     # check needed stuff
     if ( !$Param{User} ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => 'Need User!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need User!' );
         return;
     }
     $Param{User} = $Self->_ConvertTo( $Param{User}, 'utf-8' );
@@ -125,10 +129,7 @@ sub Sync {
     }
     my $Result;
     if ( $Self->{SearchUserDN} && $Self->{SearchUserPw} ) {
-        $Result = $LDAP->bind(
-            dn       => $Self->{SearchUserDN},
-            password => $Self->{SearchUserPw}
-        );
+        $Result = $LDAP->bind( dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw} );
     }
     else {
         $Result = $LDAP->bind();
@@ -207,7 +208,8 @@ sub Sync {
     my %SystemRolesByName = reverse %SystemRoles;
 
     # sync user from ldap
-    my $UserSyncMap = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UserSyncMap' . $Self->{Count} );
+    my $UserSyncMap
+        = $Self->{ConfigObject}->Get( 'AuthSyncModule::LDAP::UserSyncMap' . $Self->{Count} );
     if ($UserSyncMap) {
 
         # get whole user dn
@@ -224,7 +226,21 @@ sub Sync {
                             . 'from Kernel/Config/Defaults.pm (User* has been added!).',
                     );
                 }
-                $SyncUser{$Key} = $Entry->get_value( $UserSyncMap->{$Key} );
+
+                my $AttributeNames = $UserSyncMap->{$Key};
+                if ( ref $AttributeNames ne 'ARRAY' ) {
+                    $AttributeNames = [$AttributeNames];
+                }
+                for my $AttributeName ( @{$AttributeNames} ) {
+                    if ( $AttributeName =~ /^_/ ) {
+                        $SyncUser{$Key} = substr( $AttributeName, 1 );
+                        last;
+                    }
+                    elsif ( $Entry->get_value($AttributeName) ) {
+                        $SyncUser{$Key} = $Entry->get_value($AttributeName);
+                        last;
+                    }
+                }
 
                 # e. g. set utf-8 flag
                 $SyncUser{$Key} = $Self->_ConvertFrom(
@@ -292,10 +308,8 @@ sub Sync {
                         $Self->{GroupObject}->GroupMemberAdd(
                             GID        => $SystemGroupsByName{$Group},
                             UID        => $UserID,
-                            Permission => {
-                                rw => 1,
-                            },
-                            UserID => 1,
+                            Permission => { rw => 1, },
+                            UserID     => 1,
                         );
                     }
                 }
