@@ -1,5 +1,5 @@
 # --
-# Kernel/System/CheckItem.pm - the global spelling module
+# Kernel/System/CheckItem.pm - module to check and manipulate strings
 # Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
@@ -12,6 +12,8 @@ package Kernel::System::CheckItem;
 use strict;
 use warnings;
 
+use Email::Valid;
+
 =head1 NAME
 
 Kernel::System::CheckItem - check items
@@ -131,32 +133,7 @@ sub CheckEmail {
     my $Error = '';
 
     # email address syntax check
-    if (
-        $Param{Address}
-        !~ m{
-            ^
-            [a-zA-Z0-9_#]+
-            (?:
-                [a-zA-Z0-9_+\.&%-/=]*
-                [a-zA-Z0-9_'\.-]+
-            )?
-            @
-            (?:
-                (?:
-                    [a-zA-Z0-9]+
-                    ([a-zA-Z0-9\.-]*[a-zA-Z0-9]+)?
-                    \.+
-                    [a-zA-Z]{2,8}
-                )
-                |
-                (?:
-                    \d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}
-                )
-            )
-            $
-        }x
-        )
-    {
+    if ( !Email::Valid->address( $Param{Address} ) ) {
         $Error = "Invalid syntax";
         $Self->{ErrorType} = 'InvalidSyntax';
     }
@@ -186,13 +163,13 @@ sub CheckEmail {
         my $Resolver = Net::DNS::Resolver->new();
         if ($Resolver) {
 
-            # check if extra nameserver need to be used
+            # check if we need to use a specific name server
             my $Nameserver = $Self->{ConfigObject}->Get('CheckMXRecord::Nameserver');
             if ($Nameserver) {
                 $Resolver->nameservers($Nameserver);
             }
 
-            # A recorde lookup
+            # A-record lookup
             my $Packet = $Resolver->send( $Host, 'A' );
             if ( !$Packet ) {
                 $Self->{ErrorType} = 'InvalidDNS';
@@ -202,29 +179,12 @@ sub CheckEmail {
                     Message  => "DNS problem: " . $Resolver->errorstring(),
                 );
             }
-            elsif ( $Packet->header()->ancount() ) {
 
-                # OK
-                # print STDERR "OK A $Host ".$Packet->header->ancount()."\n";
-            }
-
-            # mx recorde lookup
             else {
-                my $Packet = $Resolver->send( $Host, 'MX' );
-                if ( !$Packet ) {
-                    $Self->{ErrorType} = 'InvalidDNS';
-                    $Error = "DNS problem: " . $Resolver->errorstring();
-                    $Self->{LogObject}->Log(
-                        Priority => 'error',
-                        Message  => "DNS problem: " . $Resolver->errorstring(),
-                    );
-                }
-                elsif ( $Packet->header()->ancount() ) {
 
-                    # OK
-                    # print STDERR "OK MX $Host ".$Packet->header->ancount()."\n";
-                }
-                else {
+                # mx record lookup
+                my @MXRecords = Net::DNS::mx( $Resolver, $Host );
+                if ( !@MXRecords ) {
                     $Error = "no mail exchanger (mx) found!";
                     $Self->{ErrorType} = 'InvalidMX';
                 }
@@ -352,7 +312,7 @@ sub CreditCardClean {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.com/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (AGPL). If you
