@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Crypt.pm - the main crypt module
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -94,16 +94,16 @@ sub new {
     # create file template object
     $Self->{FileTempObject} = Kernel::System::FileTemp->new( %{$Self} );
 
+    # reset ISA for testability and peristent environments
+    @ISA = ();
+
     # load generator crypt module
     $Self->{GenericModule} = "Kernel::System::Crypt::$Param{CryptType}";
-    return if !$Self->{MainObject}->Require( $Self->{GenericModule} );
+    return if !$Self->{MainObject}->RequireBaseClass( $Self->{GenericModule} );
 
     # time object
     $Self->{TimeObject} = Kernel::System::Time->new( %{$Self} );
 
-    # add generator crypt functions
-    @ISA = ("$Self->{GenericModule}");
-
     # call init()
     $Self->_Init();
 
