@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/CustomerCompany/Event/CustomerUserUpdate.pm - update customer users if company changes
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::CustomerCompany::Event::CustomerUserUpdate;
@@ -11,10 +12,7 @@ package Kernel::System::CustomerCompany::Event::CustomerUserUpdate;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::CustomerUser',
-    'Kernel::System::Log',
-);
+use Kernel::System::CustomerUser;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -23,6 +21,14 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # get needed objects
+    for (
+        qw( ConfigObject EncodeObject LogObject MainObject DBObject)
+        )
+    {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+
     return $Self;
 }
 
@@ -32,41 +38,34 @@ sub Run {
     # check needed stuff
     for (qw( Data Event Config UserID )) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
     for (qw( CustomerID OldCustomerID )) {
         if ( !$Param{Data}->{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_ in Data!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_ in Data!" );
             return;
         }
     }
 
     return 1 if $Param{Data}->{CustomerID} eq $Param{Data}->{OldCustomerID};
 
-    # get customer user object
-    my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+    $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new( %{$Self} );
 
-    my %CustomerUsers = $CustomerUserObject->CustomerSearch(
-        CustomerIDRaw => $Param{Data}->{OldCustomerID},
-        Valid         => 0,
+    my %CustomerUsers = $Self->{CustomerUserObject}->CustomerSearch(
+        CustomerID => $Param{Data}->{OldCustomerID},
+        Valid      => 0,
     );
 
     for my $CustomerUserLogin ( sort keys %CustomerUsers ) {
-        my %CustomerData = $CustomerUserObject->CustomerUserDataGet(
+        my %CustomerData = $Self->{CustomerUserObject}->CustomerUserDataGet(
             User => $CustomerUserLogin,
         );
 
         # we do not need to 'change' the password (this would re-hash it!)
         delete $CustomerData{UserPassword};
-        $CustomerUserObject->CustomerUserUpdate(
+        $Self->{CustomerUserObject}->CustomerUserUpdate(
             %CustomerData,
             ID             => $CustomerUserLogin,
             UserCustomerID => $Param{Data}->{CustomerID},
