@@ -1,6 +1,6 @@
 # --
 # Kernel/System/Email/Sendmail.pm - the global email send module
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -88,7 +88,16 @@ sub Send {
     print $FH ${ $Param{Header} };
     print $FH "\n";
     print $FH ${ $Param{Body} };
-    close($FH);
+
+    # Check if the filehandle was already closed because of an error
+    #   (e. g. mail too large). See bug#9251.
+    if ( !close($FH) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Can't send message: $!!",
+        );
+        return;
+    }
 
     # debug
     if ( $Self->{Debug} > 2 ) {
