@@ -12,9 +12,6 @@ package Kernel::System::Notification;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.43 $) [1];
-
 =head1 NAME
 
 Kernel::System::Notification - notification functions
@@ -104,11 +101,8 @@ sub NotificationGet {
         $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Name!' );
         return;
     }
-    my ( $Language, $Type );
-    if ( $Param{Name} =~ /^(.+?)::(.*)/ ) {
-        $Language = $Self->{DBObject}->Quote($1);
-        $Type     = $Self->{DBObject}->Quote($2);
-    }
+
+    my ( $Language, $Type ) = $Param{Name} =~ m{^(.+?)::(.*)}smx;
 
     $Self->{DBObject}->Prepare(
         SQL => 'SELECT id, notification_type, notification_charset, '
@@ -294,9 +288,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.43 $ $Date: 2012-11-20 15:36:21 $
-
-=cut
