@@ -19,9 +19,6 @@ use Kernel::System::VariableCheck qw(:all);
 
 use Kernel::System::ProcessManagement::DB::ActivityDialog;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.14 $) [1];
-
 =head1 NAME
 
 Kernel::System::ProcessManagement::DB::Activity.pm
@@ -105,7 +102,7 @@ sub new {
 
     # set lower if database is case sensitive
     $Self->{Lower} = '';
-    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+    if ( $Self->{DBObject}->GetDatabaseFunction('CaseSensitive') ) {
         $Self->{Lower} = 'LOWER';
     }
 
@@ -715,9 +712,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.14 $ $Date: 2013-01-17 03:39:21 $
-
-=cut
