@@ -1,9 +1,10 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/StandardTemplate.pm - lib for std templates
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::StandardTemplate;
@@ -11,28 +12,59 @@ package Kernel::System::StandardTemplate;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::System::Cache',
-    'Kernel::System::DB',
-    'Kernel::System::Log',
-    'Kernel::System::Valid',
-);
+use Kernel::System::Valid;
+use Kernel::System::CacheInternal;
 
 =head1 NAME
 
-Kernel::System::StandardTemplate - standard template lib
+Kernel::System::StandardTemplate - std template lib
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
-All standard template functions. E. g. to add standard template or other functions.
+All std template functions. E. g. to add std template or other functions.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 create an object
 
-    my $StandardTemplateObject = $Kernel::OM->Get('Kernel::System::StandardTemplate');
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::StandardTemplate;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $StandardTemplateObject = Kernel::System::StandardTemplate->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+        MainObject   => $MainObject,
+    );
 
 =cut
 
@@ -43,12 +75,30 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
+    # get needed objects
+    for (qw(ConfigObject LogObject DBObject EncodeObject MainObject)) {
+        if ( $Param{$_} ) {
+            $Self->{$_} = $Param{$_};
+        }
+        else {
+            die "Got no $_!";
+        }
+    }
+
+    # create additional objects
+    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
+        %{$Self},
+        Type => 'StandardTemplate',
+        TTL  => 60 * 60 * 24 * 20,
+    );
+    $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
+
     return $Self;
 }
 
-=head2 StandardTemplateAdd()
+=item StandardTemplateAdd()
 
-add new standard template
+add new std template
 
     my $ID = $StandardTemplateObject->StandardTemplateAdd(
         Name         => 'New Standard Template',
@@ -67,28 +117,13 @@ sub StandardTemplateAdd {
     # check needed stuff
     for (qw(Name ValidID Template ContentType UserID TemplateType)) {
         if ( !defined( $Param{$_} ) ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    # check if a standard template with this name already exists
-    if ( $Self->NameExistsCheck( Name => $Param{Name} ) ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "A standard template with the name '$Param{Name}' already exists.",
-        );
-        return;
-    }
-
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # sql
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => '
             INSERT INTO standard_template (name, valid_id, comments, text,
                 content_type, create_time, create_by, change_time, change_by, template_type)
@@ -98,28 +133,24 @@ sub StandardTemplateAdd {
             \$Param{ContentType}, \$Param{UserID},  \$Param{UserID},  \$Param{TemplateType},
         ],
     );
-
-    return if !$DBObject->Prepare(
-        SQL  => 'SELECT id FROM standard_template WHERE name = ? AND change_by = ?',
+    my $ID;
+    return if !$Self->{DBObject}->Prepare(
+        SQL => 'SELECT id FROM standard_template WHERE name = ? AND change_by = ?',
         Bind => [ \$Param{Name}, \$Param{UserID}, ],
     );
-
-    my $ID;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $ID = $Row[0];
     }
 
     # clear queue cache, due to Queue <-> Template relations
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => 'Queue',
-    );
+    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
 
     return $ID;
 }
 
-=head2 StandardTemplateGet()
+=item StandardTemplateGet()
 
-get standard template attributes
+get std template attributes
 
     my %StandardTemplate = $StandardTemplateObject->StandardTemplateGet(
         ID => 123,
@@ -148,18 +179,12 @@ sub StandardTemplateGet {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need ID!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need ID!' );
         return;
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # sql
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => '
             SELECT name, valid_id, comments, text, content_type, create_time, create_by,
                 change_time, change_by ,template_type
@@ -167,9 +192,8 @@ sub StandardTemplateGet {
             WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
-
     my %Data;
-    while ( my @Data = $DBObject->FetchrowArray() ) {
+    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
         %Data = (
             ID           => $Param{ID},
             Name         => $Data[0],
@@ -184,11 +208,10 @@ sub StandardTemplateGet {
             TemplateType => $Data[9],
         );
     }
-
     return %Data;
 }
 
-=head2 StandardTemplateDelete()
+=item StandardTemplateDelete()
 
 delete a standard template
 
@@ -203,45 +226,37 @@ sub StandardTemplateDelete {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need ID!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need ID!' );
         return;
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # delete queue<->std template relation
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL  => 'DELETE FROM queue_standard_template WHERE standard_template_id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # delete attachment<->std template relation
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL  => 'DELETE FROM standard_template_attachment WHERE standard_template_id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # sql
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL  => 'DELETE FROM standard_template WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # clear queue cache, due to Queue <-> Template relations
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => 'Queue',
-    );
+    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
 
     return 1;
 }
 
-=head2 StandardTemplateUpdate()
+=item StandardTemplateUpdate()
 
-update standard template attributes
+update std template attributes
 
     $StandardTemplateObject->StandardTemplateUpdate(
         ID           => 123,
@@ -261,31 +276,13 @@ sub StandardTemplateUpdate {
     # check needed stuff
     for (qw(ID Name ValidID TemplateType ContentType UserID TemplateType)) {
         if ( !defined( $Param{$_} ) ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    # check if a standard template with this name already exists
-    if (
-        $Self->NameExistsCheck(
-            Name => $Param{Name},
-            ID   => $Param{ID}
-        )
-        )
-    {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "A standard template with the name '$Param{Name}' already exists.",
-        );
-        return;
-    }
-
     # sql
-    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => '
             UPDATE standard_template
             SET name = ?, text = ?, content_type = ?, comments = ?, valid_id = ?,
@@ -298,16 +295,14 @@ sub StandardTemplateUpdate {
     );
 
     # clear queue cache, due to Queue <-> Template relations
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => 'Queue',
-    );
+    $Self->{CacheInternalObject}->CleanUp( OtherType => 'Queue' );
 
     return 1;
 }
 
-=head2 StandardTemplateLookup()
+=item StandardTemplateLookup()
 
-return the name or the standard template id
+return the name or the std template id
 
     my $StandardTemplateName = $StandardTemplateObject->StandardTemplateLookup(
         StandardTemplateID => 123,
@@ -326,7 +321,7 @@ sub StandardTemplateLookup {
 
     # check needed stuff
     if ( !$Param{StandardTemplate} && !$Param{StandardTemplateID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => 'Got no StandardTemplate or StandardTemplateID!'
         );
@@ -356,16 +351,8 @@ sub StandardTemplateLookup {
         $SQL    = 'SELECT name FROM standard_template WHERE id = ?';
         @Bind   = ( \$Param{StandardTemplateID} );
     }
-
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
-        SQL  => $SQL,
-        Bind => \@Bind,
-    );
-
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    return if !$Self->{DBObject}->Prepare( SQL => $SQL, Bind => \@Bind );
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
 
         # store result
         $Self->{"StandardTemplate$Suffix"} = $Row[0];
@@ -373,21 +360,18 @@ sub StandardTemplateLookup {
 
     # check if data exists
     if ( !exists $Self->{"StandardTemplate$Suffix"} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "Found no \$$Suffix!"
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => "Found no \$$Suffix!" );
         return;
     }
 
     return $Self->{"StandardTemplate$Suffix"};
 }
 
-=head2 StandardTemplateList()
+=item StandardTemplateList()
 
-get all valid standard templates
+get all valid std templatess
 
-    my %StandardTemplates = $StandardTemplateObject->StandardTemplateList();
+    my %StandardTemplates = $StandardTemplatesObject->StandardTemplateList();
 
 Returns:
     %StandardTemplates = (
@@ -396,7 +380,7 @@ Returns:
         3 => 'Some Name3',
     );
 
-get all standard templates
+get all std templates
 
     my %StandardTemplates = $StandardTemplateObject->StandardTemplateList(
         Valid => 0,
@@ -408,7 +392,7 @@ Returns:
         2 => 'Some Name2',
     );
 
-get standard templates from a certain type
+get std templates from a certain type
     my %StandardTemplates = $StandardTemplateObject->StandardTemplateList(
         Valid => 0,
         Type  => 'Answer',
@@ -434,8 +418,7 @@ sub StandardTemplateList {
         FROM standard_template';
 
     if ($Valid) {
-        $SQL .= ' WHERE valid_id IN (' . join ', ',
-            $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet() . ')';
+        $SQL .= ' WHERE valid_id IN (' . join ', ', $Self->{ValidObject}->ValidIDsGet() . ')';
     }
 
     my @Bind;
@@ -450,65 +433,27 @@ sub StandardTemplateList {
         push @Bind, \$Param{Type};
     }
 
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL  => $SQL,
         Bind => \@Bind,
     );
-
     my %Data;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
-
     return %Data;
 }
 
-=head2 NameExistsCheck()
-
-    return 1 if another standard template with this name already exists
-
-        $Exist = $StandardTemplateObject->NameExistsCheck(
-            Name => 'Some::Template',
-            ID => 1, # optional
-        );
-
-=cut
-
-sub NameExistsCheck {
-    my ( $Self, %Param ) = @_;
-
-    # get database object
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Prepare(
-        SQL  => 'SELECT id FROM standard_template WHERE name = ?',
-        Bind => [ \$Param{Name} ],
-    );
-
-    # fetch the result
-    my $Flag;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
-        if ( !$Param{ID} || $Param{ID} ne $Row[0] ) {
-            $Flag = 1;
-        }
-    }
-    if ($Flag) {
-        return 1;
-    }
-    return 0;
-}
-
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
