@@ -1,8 +1,6 @@
 # --
 # Kernel/System/Web/InterfaceAgent.pm - the agent interface file (incl. auth)
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: InterfaceAgent.pm,v 1.73 2012/11/20 16:02:07 mh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,9 +12,6 @@ package Kernel::System::Web::InterfaceAgent;
 use strict;
 use warnings;
 
-use vars qw($VERSION @INC);
-$VERSION = qw($Revision: 1.73 $) [1];
-
 use Kernel::Config;
 use Kernel::System::Log;
 use Kernel::System::Main;
@@ -343,10 +338,12 @@ sub Run {
         $LayoutObject = Kernel::Output::HTML::Layout->new(
             SetCookies => {
                 SessionIDCookie => $Self->{ParamObject}->SetCookie(
-                    Key     => $Param{SessionName},
-                    Value   => $NewSessionID,
-                    Expires => $Expires,
-                    Secure  => scalar $SecureAttribute,
+                    Key      => $Param{SessionName},
+                    Value    => $NewSessionID,
+                    Expires  => $Expires,
+                    Path     => $Self->{ConfigObject}->Get('ScriptAlias'),
+                    Secure   => scalar $SecureAttribute,
+                    HTTPOnly => 1,
                 ),
             },
             SessionID   => $NewSessionID,
@@ -437,7 +434,7 @@ sub Run {
         $LayoutObject->Print(
             Output => \$LayoutObject->Login(
                 Title   => 'Logout',
-                Message => 'Logout successful. Thank you for using OTRS!',
+                Message => 'Logout successful. Thank you for using %s!", "$Config{"ProductName"}',
                 %Param,
             ),
         );
@@ -871,7 +868,9 @@ sub Run {
                 $QueryString = 'Action=' . $Param{Action} . '&Subaction=' . $Param{Subaction};
             }
             my $File = $Self->{ConfigObject}->Get('PerformanceLog::File');
+            ## no critic
             if ( open my $Out, '>>', $File ) {
+                ## use critic
                 print $Out time()
                     . '::Agent::'
                     . ( time() - $Self->{PerformanceLogStart} )
@@ -933,9 +932,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.73 $ $Date: 2012/11/20 16:02:07 $
-
-=cut
