@@ -9,9 +9,6 @@
 
 /*global jsPlumb */
 
-// Don't check this file for "dangling _", because of some needed JointJS functionality uses this
-/*jslint nomen: false*/
-
 "use strict";
 
 var Core = Core || {};
@@ -30,8 +27,6 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
     var Elements = {},
         ActivityBoxHeight = 80;
 
-
-
     function EscapeHTML(Content) {
         return Content
             .replace(/&/g, '&amp;')
@@ -151,13 +146,17 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             .bind('mouseenter.Activity', function() {
                 TargetNS.ShowActivityTooltip($(this));
                 TargetNS.ShowActivityDeleteButton($(this));
+                TargetNS.ShowActivityEditButton($(this));
                 if (TargetNS.DragActivityItem) {
                     $(this).addClass('ReadyToDrop');
                 }
+                $(this).addClass('Hovered');
             })
             .bind('mouseleave.Activity', function() {
                 $('#DiagramTooltip').hide();
                 $(this).removeClass('ReadyToDrop').find('.DiagramDeleteLink').remove();
+                $(this).removeClass('ReadyToDrop').find('.DiagramEditLink').remove();
+                $(this).removeClass('Hovered');
             })
             .bind('dblclick.Activity', function() {
                 var Path = Core.Config.Get('Config.PopupPathActivity') + "EntityID=" + EntityID + ";ID=" + ActivityID;
@@ -187,17 +186,39 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         Elements[EntityID] = $('#' + EntityID);
     };
 
-    TargetNS.CreateActivityDummy = function () {
-        if (!$('#Dummy').length) {
-            $('#Canvas').append('<div class="Activity" id="Dummy"><span>Dummy</span></div>').find('#Dummy').css({
-                top: '10px',
-                left: '10px'
-            });
+    TargetNS.CreateActivityDummy = function (StartActivityID) {
+        var StartActivityPosition, DummyPosition, CanvasSize = {},
+            Activities = Core.Agent.Admin.ProcessManagement.ProcessData.Activity;
+
+        if ($('#Dummy').length) {
+            $('#Dummy').remove();
         }
+
+        CanvasSize.width = $('#Canvas').width();
+        CanvasSize.height = $('#Canvas').height();
+
+        // get position of start activity to calculate position of dummy
+        StartActivityPosition = $('#' + StartActivityID).position();
+        DummyPosition = StartActivityPosition;
+        DummyPosition.top += 120;
+        DummyPosition.left += 150;
+
+        // check if DummyPosition is out of canvas and correct position
+        if ((CanvasSize.width - 85) <= DummyPosition.left) {
+            DummyPosition.left -= 250;
+        }
+        if ((CanvasSize.height - 115) <= DummyPosition.top) {
+            DummyPosition.top -= 240;
+        }
+
+        $('#Canvas').append('<div class="Activity" id="Dummy"><span>Dummy</span></div>').find('#Dummy').css({
+            top: DummyPosition.top,
+            left: DummyPosition.left
+        });
     };
 
     TargetNS.ShowTransitionTooltip = function (Connection, StartActivity, EndActivity) {
-        var $tooltip = $('#DiagramTooltip'),
+        var $Tooltip = $('#DiagramTooltip'),
             $Element = $(Connection.canvas),
             $TitleElement = $Element.clone(),
             text,
@@ -206,7 +227,10 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             ElementID = Connection.id,
             CurrentProcessEntityID = $('#ProcessEntityID').val(),
             PathInfo = Core.Agent.Admin.ProcessManagement.ProcessData.Process[CurrentProcessEntityID].Path,
-            AssignedTransitionActions = [];
+            AssignedTransitionActions = [],
+            CanvasWidth, CanvasHeight,
+            TooltipWidth, TooltipHeight;
+
 
         $TitleElement.find('a').remove();
         text = '<h4>' + EscapeHTML($TitleElement.text()) + '</h4>';
@@ -215,20 +239,13 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             return false;
         }
 
-        if (!$tooltip.length) {
-            $tooltip = $('<div id="DiagramTooltip"></div>').css('display', 'none').appendTo('#Canvas');
+        if (!$Tooltip.length) {
+            $Tooltip = $('<div id="DiagramTooltip"></div>').css('display', 'none').appendTo('#Canvas');
         }
-        else if ($tooltip.is(':visible')) {
-            $tooltip.hide();
+        else if ($Tooltip.is(':visible')) {
+            $Tooltip.hide();
         }
 
-        // calculate tooltip position
-        // x: x-coordinate of canvas + x-coordinate of element within canvas + width of element
-        position.x = parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + 30;
-
-        // y: y-coordinate of canvas + y-coordinate of element within canvas + height of element
-        position.y = parseInt($Element.css('top'), 10) + 15;
-
         $.each(PathInfo, function(Activity, Transition) {
             if (Activity === StartActivity && typeof Transition[ElementID] !== 'undefined' && typeof Transition[ElementID].TransitionAction !== 'undefined') {
                 AssignedTransitionActions = Transition[ElementID].TransitionAction;
@@ -248,8 +265,44 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         }
         text += "</ul>";
 
-        $tooltip
-            .html(text)
+        $Tooltip.html(text);
+
+        // calculate tooltip position
+        // x: x-coordinate of canvas + x-coordinate of element within canvas + width of element
+        //position.x = parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + 30;
+        //
+        // y: y-coordinate of canvas + y-coordinate of element within canvas + height of element
+        //position.y = parseInt($Element.css('top'), 10) + 15;
+
+        // calculate tooltip position
+        // if activity box is at the right border of the canvas, switch tooltip to the left side of the box
+        CanvasWidth = $('#Canvas').width();
+        TooltipWidth = $Tooltip.width();
+
+        // If activity does not fit in canvas, generate tooltip on the left side
+        if (CanvasWidth < (parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + TooltipWidth)) {
+            // x: x-coordinate of element within canvas - width of tooltip
+            position.x = parseInt($Element.css('left'), 10) - TooltipWidth - 5;
+        }
+        // otherwise put tooltip on the right side (default behaviour)
+        else {
+            // x: x-coordinate of canvas + x-coordinate of element within canvas + width of element
+            position.x = parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + 40;
+        }
+
+        // if activity box is at the bottom border of the canvas, set tooltip y-coordinate to the top as far as needed
+        CanvasHeight = $('#Canvas').height();
+        TooltipHeight = $Tooltip.height();
+
+        // y-coordinate
+        if (parseInt($Element.css('top'), 10) + TooltipHeight + 15 > CanvasHeight) {
+            position.y = CanvasHeight - TooltipHeight - 15;
+        }
+        else {
+            position.y = parseInt($Element.css('top'), 10) + 15;
+        }
+
+        $Tooltip
             .css('top', position.y)
             .css('left', position.x)
             .show();
@@ -263,7 +316,9 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             ActivityDialogs,
             ElementID = $Element.attr('id'),
             CanvasWidth,
-            TooltipWidth;
+            CanvasHeight,
+            TooltipWidth,
+            TooltipHeight;
 
         if (typeof Activity[$Element.attr('id')] === 'undefined') {
             return false;
@@ -315,11 +370,20 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         // otherwise put tooltip on the right side (default behaviour)
         else {
             // x: x-coordinate of canvas + x-coordinate of element within canvas + width of element
-            position.x = parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + 10;
+            position.x = parseInt($Element.css('left'), 10) + parseInt($Element.width(), 10) + 15;
         }
 
+        // if activity box is at the bottom border of the canvas, set tooltip y-coordinate to the top as far as needed
+        CanvasHeight = $('#Canvas').height();
+        TooltipHeight = $Tooltip.height();
+
         // y-coordinate
-        position.y = parseInt($Element.css('top'), 10) + 10;
+        if (parseInt($Element.css('top'), 10) + TooltipHeight + 10 > CanvasHeight) {
+            position.y = CanvasHeight - TooltipHeight - 10;
+        }
+        else {
+            position.y = parseInt($Element.css('top'), 10) + 10;
+        }
 
         $Tooltip
             .css('top', position.y)
@@ -355,6 +419,33 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             });
     };
 
+    TargetNS.ShowActivityEditButton = function ($Element) {
+        var $edit = $('.DiagramEditLink').clone(),
+            position = { x: 0, y: 0},
+            Activity = Core.Agent.Admin.ProcessManagement.ProcessData.Activity,
+            ElementID = $Element.attr('id');
+
+        if (typeof Activity[ElementID] === 'undefined') {
+            return false;
+        }
+
+        if ($edit.is(':visible')) {
+            $edit.hide();
+        }
+
+        $Element.append($edit);
+
+        $edit
+            .show()
+            .unbind('click')
+            .bind('click', function () {
+                var Path = Core.Config.Get('Config.PopupPathActivity') + "EntityID=" + ElementID + ";ID=" + Activity[ElementID].ID;
+                Core.Agent.Admin.ProcessManagement.ShowOverlay();
+                Core.UI.Popup.OpenPopup(Path, 'Activity');
+                return false;
+            });
+    };
+
     TargetNS.ShowActivityLoader = function (EntityID) {
         if (typeof Elements[EntityID] !== 'undefined') {
             $('#' + EntityID).find('span').hide().parent().find('.Loader').show();
@@ -386,6 +477,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         // remove HTML elements
         $('#DiagramTooltip').hide();
         $('#' + EntityID).find('.DiagramDeleteLink').remove();
+        $('#' + EntityID).find('.DiagramEditLink').remove();
 
         // if Activity is StartActivity, this Activity cannot be removed...
         if (Config.Process[ProcessEntityID].StartActivity === EntityID) {
@@ -458,7 +550,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                 source: 'StartEvent',
                 target: EntityID,
                 anchor: 'Continuous',
-                endpoint: [ 'Blank' ],
+                endpoint: 'Blank',
                 detachable: true,
                 reattach: true,
                 overlays: [
@@ -471,12 +563,15 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         }
     };
 
+    TargetNS.LastTransitionDetails = {};
+
     TargetNS.CreateTransition = function (StartElement, EndElement, EntityID, TransitionName) {
 
         var Config = Core.Agent.Admin.ProcessManagement.ProcessData,
             ProcessEntityID = $('#ProcessEntityID').val(),
             Path = Config.Process[ProcessEntityID].Path,
-            StartActivity, EndActivity, OldActivity, Connection;
+            StartActivity, EndActivity, OldActivity, Connection,
+            PopupPath;
 
         StartActivity = Elements[StartElement];
         if (EndElement === "Dummy") {
@@ -500,9 +595,12 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             }
         }
 
+        PopupPath = Core.Config.Get('Config.PopupPathPath') + "ProcessEntityID=" + ProcessEntityID + ";TransitionEntityID=" + EntityID + ";StartActivityID=" + StartElement;
+
         Connection = jsPlumb.connect({
             connector: [ 'Flowchart', { curviness: 0, margin: -1, showLoopback:false } ],
             paintStyle: { strokeStyle: "#000", lineWidth: 2 },
+            hoverPaintStyle: { strokeStyle: "#FF9922", lineWidth: 2 },
             source: StartActivity,
             target: EndActivity,
             anchor: 'Continuous',
@@ -518,6 +616,11 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                 [ "PlainArrow", { location: -15, width: 20, length: 15 } ],
                 [ "Label", { label: EscapeHTML(TransitionName), location: 0.5, cssClass: 'TransitionLabel', id: EntityID, events: {
                     mouseenter: function(labelOverlay, originalEvent) {
+                        TargetNS.LastTransitionDetails = {
+                            LabelOverlay: labelOverlay,
+                            StartElement: StartElement,
+                            EndElement: EndElement
+                        };
                         TargetNS.HighlightTransitionLabel(labelOverlay, StartElement, EndElement);
                         originalEvent.stopPropagation();
                         return false;
@@ -533,6 +636,43 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                 "TransitionID": EntityID
             }
         });
+
+        Connection.bind('mouseenter', function (ActiveConnection) {
+            var Overlays = Connection.getOverlays();
+            $.each(Overlays, function (Id, Overlay) {
+                if (Overlay.type !== 'Label') {
+                    return;
+                }
+
+                // add class to label
+                $(Overlay.canvas).addClass('Hovered');
+            });
+        });
+
+        Connection.bind('mouseexit', function (ActiveConnection) {
+            var Overlays = Connection.getOverlays();
+            $.each(Overlays, function (Id, Overlay) {
+                if (Overlay.type !== 'Label') {
+                    return;
+                }
+
+                // remove hover class from label
+                $(Overlay.canvas).removeClass('Hovered');
+            });
+        });
+
+        Connection.bind('dblclick', function(Connection, Event) {
+            var EndActivity = Connection.endpoints[1];
+            // Do not open path dialog for dummy connections
+            // dblclick on overlays (e.g. labels) propagate to the connection
+            // prevent opening path dialog twice if clicked on label
+            if (EndActivity !== 'Dummy' && !$(Event.srcElement).hasClass('TransitionLabel')) {
+                Core.Agent.Admin.ProcessManagement.ShowOverlay();
+                Core.UI.Popup.OpenPopup(PopupPath, 'Path');
+            }
+            Event.stopPropagation();
+            return false;
+        });
     };
 
     TargetNS.HighlightTransitionLabel = function(Connection, StartActivity, EndActivity) {
@@ -555,7 +695,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         }
 
         if (!$(Connection.canvas).find('.Delete').length) {
-            $(Connection.canvas).append('<a class="Delete" href="#">x</a>').find('.Delete').bind('click', function(Event) {
+            $(Connection.canvas).append('<a class="Delete" title="' + Core.Agent.Admin.ProcessManagement.Localization.TransitionDeleteLink + '" href="#">x</a>').find('.Delete').bind('click', function(Event) {
                 ShowRemoveEntityCanvasConfirmationDialog('Path', Config.Transition[TransitionEntityID].Name, TransitionEntityID, function () {
                     jsPlumb.detach(Connection.component);
                     delete Path[StartActivityID][TransitionEntityID];
@@ -567,6 +707,21 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             });
         }
 
+        if (!$(Connection.canvas).find('.Edit').length) {
+            $(Connection.canvas).append('<a class="Edit" title="' + Core.Agent.Admin.ProcessManagement.Localization.TransitionEditLink + '" href="#">&gt;</a>').find('.Edit').bind('click', function(Event) {
+                if (EndActivity !== 'Dummy') {
+                    Core.Agent.Admin.ProcessManagement.ShowOverlay();
+                    Core.UI.Popup.OpenPopup(PopupPath, 'Path');
+                }
+                Event.stopPropagation();
+                return false;
+            });
+        }
+
+        // highlight label
+        $(Connection.canvas).addClass('Hovered');
+        Connection.component.setPaintStyle({ strokeStyle: "#FF9922", lineWidth: '2' });
+
         // show tooltip with assigned transition actions
         TargetNS.ShowTransitionTooltip(Connection, StartActivity, EndActivity);
 
@@ -586,6 +741,8 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             $(Connection.canvas).removeClass('ReadyToDrop');
             TargetNS.DragTransitionActionTransition = {};
         }
+        $(Connection.canvas).removeClass('Hovered');
+        Connection.component.setPaintStyle({ strokeStyle: "#000", lineWidth: '2' });
     };
 
     TargetNS.DragActivityItem = false;
@@ -640,7 +797,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                     else {
 
                         // Create dummy activity to use for initial transition
-                        TargetNS.CreateActivityDummy();
+                        TargetNS.CreateActivityDummy(StartActivityID);
 
                         // Create transition between this Activity and DummyElement
                         TargetNS.CreateTransition(StartActivityID, 'Dummy', TransitionID);
@@ -653,6 +810,14 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         });
 
         TargetNS.MakeDraggable();
+
+        $('div.TransitionLabel')
+            .delegate('a.Delete', 'mouseenter', function () {
+                TargetNS.HighlightTransitionLabel(TargetNS.LastTransitionDetails.LabelOverlay, TargetNS.LastTransitionDetails.StartElement, TargetNS.LastTransitionDetails.EndElement);
+            })
+            .delegate('a.Delete', 'mouseleave', function () {
+                TargetNS.UnHighlightTransitionLabel(TargetNS.LastTransitionDetails.LabelOverlay);
+            });
     };
 
     TargetNS.MakeDraggable = function() {
@@ -662,6 +827,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
             start: function() {
                 $('#DiagramTooltip').hide();
                 $(this).find('.DiagramDeleteLink').remove();
+                $(this).find('.DiagramEditLink').remove();
             },
             stop: function() {
                 TargetNS.UpdateElementPosition($(this));
@@ -697,14 +863,11 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
         // based on the saved layout information (if available)
         $('#Canvas').width(CanvasWidth).height(CanvasHeight);
 
-        // Init JsPlumb in Canvas mode (because of bugs with SVG in jQ1.6 in IE9)
-        jsPlumb.setRenderMode(jsPlumb.CANVAS);
-
         // reset, because at this point (initial draw or redraw), there cannot be a saved connection
         TargetNS.LatestConnectionTransitionID = undefined;
 
         // init binding to connection changes
-        jsPlumb.bind('jsPlumbConnection', function(Data) {
+        jsPlumb.bind('connection', function(Data, OriginalEvent) {
             var Config = Core.Agent.Admin.ProcessManagement.ProcessData,
                 ProcessEntityID = $('#ProcessEntityID').val(),
                 Path = Config.Process[ProcessEntityID].Path,
@@ -716,6 +879,7 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
 
                 // Correct transition arrows
                 Data.connection.setPaintStyle({ strokeStyle: "#000", lineWidth: 2 });
+                Data.connection.setHoverPaintStyle({ strokeStyle: "#FF9922", lineWidth: 2 });
                 Data.connection.addOverlay([ "PlainArrow", { location: -15, width: 20, length: 15 } ]);
 
             }
@@ -762,10 +926,16 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
                 // Correcting connection: setting parameters and overlays
                 Data.connection.setParameter('TransitionID', TransitionID);
                 Data.connection.setPaintStyle({ strokeStyle: "#000", lineWidth: 2 });
+                Data.connection.setHoverPaintStyle({ strokeStyle: "#FF9922", lineWidth: 2 });
                 Data.connection.addOverlay([ "Diamond", { location: 18, width: 15, length: 25, paintStyle: { fillStyle: '#FFF', outlineWidth: 1, outlineColor: '#000'} } ]);
                 Data.connection.addOverlay([ "PlainArrow", { location: -15, width: 20, length: 15 } ]);
                 Data.connection.addOverlay([ "Label", { label: EscapeHTML(TransitionName), location: 0.5, cssClass: 'TransitionLabel', id: TransitionID, events: {
                     mouseenter: function(labelOverlay, originalEvent) {
+                        TargetNS.LastTransitionDetails = {
+                            LabelOverlay: labelOverlay,
+                            StartElement: Data.sourceId,
+                            EndElement: Data.targetId
+                        };
                         TargetNS.HighlightTransitionLabel(labelOverlay, Data.sourceId, Data.targetId);
                     },
                     mouseexit: function(labelOverlay, originalEvent) {
@@ -811,4 +981,4 @@ Core.Agent.Admin.ProcessManagement.Canvas = (function (TargetNS) {
     return TargetNS;
 }(Core.Agent.Admin.ProcessManagement.Canvas || {}));
 
-/*jslint nomen: true*/
\ No newline at end of file
+/*jslint nomen: true*/
